Clazz.declarePackage("JSV.api");
Clazz.declareInterface(JSV.api, "PanelListener");
;//5.0.1-v7 Tue May 20 13:40:34 CDT 2025
